Skip to contents

Load dummy data that help understand the methods of geoimp.

Usage

dummy_data(res = 1, n_poly = 2)

Arguments

res

Resolution of the local population raster. Defaults to 1x1 cells.

n_poly

Number of areal polygons. Can either be one or two polygons.

Value

A list with three datasets:

  • survey: A fake survey dataset of class sf containing point data and two attribute columns on place types and income.

  • areas: One or two (depending on n_poly) polygons of class sfc that symbolize administrative areas.

  • pop: A fake population raster of class SpatRaster.

  • income: A fake income raster of class SpatRaster.

All datasets have a local CRS with coordinates ranging from 0 to 4.

Examples

dummy_data(res = 0.5)
#> $survey
#> Simple feature collection with 50 features and 2 fields
#> Geometry type: POINT
#> Dimension:     XY
#> Bounding box:  xmin: 1.166667 ymin: 1.166667 xmax: 2.833333 ymax: 2.833333
#> Projected CRS: +proj=tmerc +lat_0=0 +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs
#> First 10 features:
#>    place_type    income                  geometry
#> 1     Village 3001-4000 POINT (2.833333 1.166667)
#> 2     Village 3001-4000 POINT (2.833333 1.166667)
#> 3     Village 1001-2000 POINT (2.833333 1.166667)
#> 4        City    <=1000 POINT (2.833333 1.166667)
#> 5     Village 2001-3000 POINT (2.833333 1.166667)
#> 6     Village    <=1000 POINT (2.833333 1.166667)
#> 7        City    <=1000 POINT (2.833333 1.166667)
#> 8        Town 3001-4000 POINT (2.833333 1.166667)
#> 9     Village     >4000 POINT (2.833333 1.166667)
#> 10       City    <=1000 POINT (2.833333 1.166667)
#> 
#> $areas
#> Geometry set for 2 features 
#> Geometry type: POLYGON
#> Dimension:     XY
#> Bounding box:  xmin: -0.5 ymin: -0.5 xmax: 4.5 ymax: 4.5
#> Projected CRS: +proj=tmerc +lat_0=0 +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs
#> POLYGON ((-0.5 -0.5, 4.5 4.5, 4.5 -0.5, -0.5 -0...
#> POLYGON ((-0.5 4.5, 4.5 4.5, -0.5 -0.5, -0.5 4.5))
#> 
#> $pop
#> class       : SpatRaster
#> size        : 10, 10, 1  (nrow, ncol, nlyr)
#> resolution  : 0.5, 0.5  (x, y)
#> extent      : -0.5, 4.5, -0.5, 4.5  (xmin, xmax, ymin, ymax)
#> coord. ref. : +proj=tmerc +lat_0=0 +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs
#> source(s)   : memory
#> name        :  pop
#> min value   :   50
#> max value   : 2500
#> 
#> $income
#> class       : SpatRaster
#> size        : 10, 10, 1  (nrow, ncol, nlyr)
#> resolution  : 0.5, 0.5  (x, y)
#> extent      : -0.5, 4.5, -0.5, 4.5  (xmin, xmax, ymin, ymax)
#> coord. ref. : +proj=tmerc +lat_0=0 +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs
#> source(s)   : memory
#> name        :         pop
#> min value   :  458.333333
#> max value   : 4580.307617
#>