Skip to contents

Report on progress while evaluating an R expression. This function is a simple wrapper / re-export of with_progress that sets a more convenient default for a handler.

Usage

with_progress(expr, handlers = handler_geoimp(), ...)

Arguments

expr

An R expression to evaluate.

handlers

A progression handler or a list of them. If NULL or an empty list, progress updates are ignored. Defaults to a custom version of handler_cli.

...

Further arguments passed to with_progress.

Value

Returns the value of the expression.