A synthetic dataset containing three survey items on 1. the place of residence, 2. a self-assessment of the place category, 3. a self-assessment of political internet use.
Format
A dataframe with 2,000 rows and 3 variables:
internet_polFake answers to the question "How often do you use the internet to stay informed about politics?" Generated using weighted sampling based on zip-code level WiFi data by WiGLE.
place_catFake answers to the question "Please describe the place where you live." Generated using weighted sampling based on gridded population data at a 1km resolution by WorldPop.
locationLocations where the fake respondents live, aggregated to the local administrative unit (LAU) level. Generated using weighted sampling based on data by GISCO.